% Copyright Keysight Technologies 2011-2018
%
% Keysight IVI-COM Driver Example Program
%
% Creates a driver object, reads a few Identity interface
% properties, and checks the instrument error queue.
% May include additional instrument specific functionality.
%
% See driver help topic "Programming with the IVI-COM Driver in Various Development Environments"
% for additional programming information.
%
% Runs in simulation mode without an instrument.

disp(blanks(1)');
disp('  ML_WaveformAcq');

% Create driver instance
driver = instrument.driver.AgInfiniiVision();

% Edit resource and options as needed.  Resource is ignored if option Simulate=true
resourceDesc = 'GPIB0::7::INSTR';

initOptions = 'QueryInstrStatus=true, Simulate=true, DriverSetup= Model=, Trace=false';
idquery = true;
reset   = true;

driver.Initialize(resourceDesc, idquery, reset, initOptions);
disp('Driver Initialized');

% Print a few IIviDriver.Identity properties
disp(['Identifier:      ', driver.Identity.Identifier]);
disp(['Revision:        ', driver.Identity.Revision]);
disp(['Vendor:          ', driver.Identity.Vendor]);
disp(['Description:     ', driver.Identity.Description]);
disp(['InstrumentModel: ', driver.Identity.InstrumentModel]);
disp(['FirmwareRev:     ', driver.Identity.InstrumentFirmwareRevision]);
disp(['Serial #:        ', driver.DeviceSpecific.System.SerialNumber]);
simulate = driver.DriverOperation.Simulate;
if simulate == true
    disp(blanks(1));
    disp('Simulate:        True');
else
    disp('Simulate:        False');
end
disp(blanks(1));

% Reset instrument and load the default setup.
driver.DeviceSpecific.Utility.Reset();

% Initiate the acquisition and return the acquired waveform data
driver.DeviceSpecific.Measurements.AutoSetup();
driver.DeviceSpecific.Measurements.Initiate();

%Set Trigger (EDGE, PULSe, PATTern, etc., and input source.
%Set trigger Mode
driver.DeviceSpecific.Trigger2.Type = 1;
Triggermode = driver.DeviceSpecific.Trigger2.Type;
disp(['Trigger Mode :        ', Triggermode]);
disp(blanks(1));

%Set EDGE trigger parameters. */
driver.DeviceSpecific.Trigger4.Source = 'Channel1';
Triggersource = driver.DeviceSpecific.Trigger4.Source;
disp(['Trigger Edge Soruce :        ', Triggersource]);
disp(blanks(1));

driver.DeviceSpecific.Trigger4.Level = 0.1;
Triggerlevel = driver.DeviceSpecific.Trigger4.Level;
disp('Trigger Edge Level (V)');         disp( Triggerlevel);
disp(blanks(1));

driver.DeviceSpecific.Trigger4.Edge.Slope = 1;
Triggerslope = driver.DeviceSpecific.Trigger4.Edge.Slope;
disp(['Trigger Edge Slope :        ', Triggerslope]);
disp(blanks(1));

%Set vertical scale and offset.
[IRepcap] = driver.DeviceSpecific.Channels.Item(driver.DeviceSpecific.Channels.Name(int32(1)));
IRepcap.Scale = 0.05;
vScale = IRepcap.Scale;
disp('Channel 1 Vertical Scale:');
disp(vScale);
disp(blanks(1));

IRepcap.Offset = -1.5;
vOffset =    IRepcap.Offset;
disp('Channel 1 Vertical Offset:');
disp( vOffset);
disp(blanks(1));

% Set horizontal scale and offset. */
driver.DeviceSpecific.Timebase.HorizontalScale =  0.0002;
hScale = driver.DeviceSpecific.Timebase.HorizontalScale;
disp('Timebase Scale:');
disp( hScale);
disp(blanks(1));

driver.DeviceSpecific.Acquisition3.StartTime = 0.00;
startTime = driver.DeviceSpecific.Acquisition3.StartTime;
disp('Acquisition Start Time: ');
disp(startTime);
disp(blanks(1));

%Set the acquisition type (NORMal, PEAK, AVERage, or HRESolution).
driver.DeviceSpecific.Acquisition3.Type = 0;
acqType = driver.DeviceSpecific.Acquisition3.Type;
disp(['Acquisition Type :        ', acqType]);
disp(blanks(1));

% Capture an acquisition using :DIGitize.
driver.DeviceSpecific.Measurements.AutoSetup();
driver.DeviceSpecific.Measurements.Initiate();

%Analyze the captured waveform.Make a couple of measurements.
driver.DeviceSpecific.Measurements3.Configuration.Source2 = 'Channel1';
Source = driver.DeviceSpecific.Measurements3.Configuration.Source2;
disp(['Measure Source :        ', Source]);
disp(blanks(1));

frequency = 0.0;
[IRepcap] = driver.DeviceSpecific.Measurements3.Item2(driver.DeviceSpecific.Measurements.Name(int32(1)));
IRepcap.ReadWaveformMeasurement(2, 1000);
disp('Frequency:');
disp(frequency);

amp = 0.0;
IRepcap.ReadWaveformMeasurement(15, 1000);
disp('Vertical Amplitude: ');
disp(amp);
disp(blanks(1));

% Read screen image.

try size = driver.DeviceSpecific.Display4.GetScreenBitmap(2, 0);
catch ME, 
    %disp(ME.message);
    if size == 0
        % Note that for PXI-based models (e.g. M924x), the Soft Front Panel
        % needs to be active for Display::GetScreenBitmap to work.
        disp(' GetScreenBitmap: Failed to obtain screenshot.');
    end
    end

disp('Screen Image byte:');
disp(size);

% Download waveform data Set the waveform points mode.
driver.DeviceSpecific.Waveform2.PointMode = 2;
wfmPointMode = driver.DeviceSpecific.Waveform2.PointMode;
disp(['Waveform Points Mode :        ', wfmPointMode]);
disp(blanks(1));

% Get the number of waveform points available.
wfmPointCount = driver.DeviceSpecific.Waveform2.PointCount;
disp('Waveform Points Available: ');
disp(wfmPointCount);

% Set the waveform source.
driver.DeviceSpecific.Waveform2.Source = 'Channel1';
Wfm_Source = driver.DeviceSpecific.Waveform2.Source;
disp(['Waveform Source :        ', Wfm_Source]);
disp(blanks(1));

% Choose the format of the data returned (WORD, BYTE, ASCII):
driver.DeviceSpecific.Waveform2.DataFormat = 1;
Wfm_format =  driver.DeviceSpecific.Waveform2.DataFormat;
disp(['Waveform Format :        ', Wfm_format]);
disp(blanks(1));

%   Display the waveform settings:
Val = driver.DeviceSpecific.Waveform2.Preamble();
wavFormat = Val();

if wavFormat == 0.0
    
    fprintf('Waveform format:           BYTE');
    
elseif (wavFormat == 1.0)
    
    sprintf('Waveform Format:           WORD');
    
elseif (wavFormat == 2.0)
    
    fprintf('Waveform Format:           ASCii');
end

aType = Val(1);

if aType == 0.0
    
    fprintf('Acquire Type:              NORMal');
    
elseif aType == 1.0
    
    fprintf('Acquire Type:              PEAK');
    
elseif aType == 2.0
    
    fprintf('Acquire Type:              AVERage');
    
else  aType == 3.0;
    
    fprintf('Acquire Type:              HRESolution');
end

wavPoints = Val(2);
disp('Waveform Points:           ');
disp(wavPoints);

avgCount = Val(3);
disp('Waveform Average Count:    ');
disp(avgCount);

xIncrement = Val(4);
disp('Waveform X Increment:       ');
disp(xIncrement);

xOrigin = Val(5);
disp('Waveform X Origin:         ');
disp(xOrigin);

xReference = Val(6);
disp('Waveform X Reference:      ');
disp(xReference);

yIncrement = Val(7);
disp('Waveform Y Increment:      ');
disp(yIncrement)

yOrigin = Val(8);
disp('Waveform Y Origin:         ');
disp(yOrigin);

yReference = Val(8);
disp('Waveform Y Reference:      ');
disp(yReference);
% Read waveform data
[IRepcap] = driver.DeviceSpecific.Measurements3.Item2(driver.DeviceSpecific.Measurements.Name(int32(1)));
[WaveformArray,InitialX,XIncrement] = IRepcap.ReadWaveform(1000);
Array_Length = length(WaveformArray);
disp('Number of data values:');
disp(Array_Length)

% Print out the first ten values
disp('Waveform Data (First 10 points):');
for i= 1:10
    disp(WaveformArray(i))
end

% Check instrument for errors
errorNum = -1;
errorMsg = ('');
disp(blanks(1)');

while (errorNum ~= 0)
    [errorNum, errorMsg] = driver.Utility.ErrorQuery();
    disp(['ErrorQuery: ', num2str(errorNum), ', ', errorMsg]);
end

if driver.Initialized
    driver.Close();
    disp('Driver Closed');
end

disp('Done');
disp(blanks(1)');

